@@ -30,9 +30,10 @@ pub(in crate::exec) fn exec_pty(
     spawn_noexec_handler: Option<SpawnNoexecHandler>,
     mut command: Command,
     user_tty: UserTerm,
+    pty_owner: &User,
 ) -> io::Result<ExitReason> {
     // Allocate a pseudoterminal.
-    let pty = get_pty()?;
+    let pty = get_pty(pty_owner)?;
 
     // Create backchannels to communicate with the monitor.
     let mut backchannels = BackchannelPair::new().map_err(|err| {
@@ -93,20 +94,22 @@ pub(in crate::exec) fn exec_pty(
 
     // FIXME: maybe all these boolean flags should be on a dedicated type.
 
-    // Whether we're running on a pipeline
-    let mut pipeline = false;
     // Whether the command should be executed in the background (this is not the `-b` flag)
     let mut exec_bg = false;
     // Whether the user's terminal is in raw mode or not.
     let mut term_raw = false;
+    // Whether to preserve oflag for the terminal
+    let mut preserve_oflag = false;
 
     // Check if we are part of a pipeline.
     // FIXME: Here's where we should intercept the IO streams if we want to implement IO logging.
     // FIXME: ogsudo creates pipes for the IO streams and uses events to read from the strams to
     // the pipes. Investigate why.
-    if !io::stdin().is_terminal() {
+    if !io::stdin().is_terminal_for_pgrp(parent_pgrp) {
         dev_info!("stdin is not a terminal, command will inherit it");
-        pipeline = true;
+        if io::stdin().is_pipe() {
+            exec_bg = true;
+        }
         command.stdin(Stdio::inherit());
 
         if foreground && parent_pgrp != sudo_pid {
@@ -117,17 +120,26 @@ pub(in crate::exec) fn exec_pty(
         }
     }
 
-    if !io::stdout().is_terminal() {
+    if !io::stdout().is_terminal_for_pgrp(parent_pgrp) {
         dev_info!("stdout is not a terminal, command will inherit it");
-        pipeline = true;
+        if io::stdout().is_pipe() {
+            exec_bg = true;
+            preserve_oflag = true;
+        }
         command.stdout(Stdio::inherit());
     }
 
-    if !io::stderr().is_terminal() {
+    if !io::stderr().is_terminal_for_pgrp(parent_pgrp) {
         dev_info!("stderr is not a terminal, command will inherit it");
         command.stderr(Stdio::inherit());
     }
 
+    // If there is another process later in the pipeline, don't interfere
+    // with its access to the Tty
+    if io::stdout().is_pipe() {
+        foreground = false;
+    }
+
     // Copy terminal settings from `/dev/tty` to the pty.
     if let Err(err) = user_tty.copy_to(&pty.follower) {
         dev_error!("cannot copy terminal settings to pty: {err}");
@@ -135,10 +147,10 @@ pub(in crate::exec) fn exec_pty(
     }
 
     // Start in raw mode unless we're part of a pipeline or backgrounded.
-    if foreground && !pipeline && !exec_bg {
+    if foreground && !exec_bg {
         // Clearer this way that set_raw_mode only conditionally runs
         #[allow(clippy::collapsible_if)]
-        if user_tty.set_raw_mode(false).is_ok() {
+        if user_tty.set_raw_mode(false, preserve_oflag).is_ok() {
             term_raw = true;
         }
     }
@@ -158,6 +170,10 @@ pub(in crate::exec) fn exec_pty(
         }
     };
 
+    if !foreground {
+        tty_pipe.disable_input(&mut registry);
+    }
+
     // SAFETY: There should be no other threads at this point.
     let ForkResult::Parent(monitor_pid) = (unsafe { fork() }).map_err(|err| {
         dev_error!("cannot fork monitor process: {err}");
@@ -172,7 +188,7 @@ pub(in crate::exec) fn exec_pty(
         match exec_monitor(
             pty.follower,
             command,
-            foreground && !pipeline && !exec_bg,
+            foreground && !exec_bg,
             &mut backchannels.monitor,
             original_set,
         ) {
@@ -207,12 +223,10 @@ pub(in crate::exec) fn exec_pty(
     drop(backchannels.monitor);
 
     // Send green light to the monitor after closing the follower.
-    retry_while_interrupted(|| backchannels.parent.send(&MonitorMessage::ExecCommand)).map_err(
-        |err| {
-            dev_error!("cannot send green light to monitor: {err}");
-            err
-        },
-    )?;
+    retry_while_interrupted(|| backchannels.parent.send(&MonitorMessage::Edge)).map_err(|err| {
+        dev_error!("cannot send green light to monitor: {err}");
+        err
+    })?;
 
     let mut closure = ParentClosure::new(
         monitor_pid,
@@ -223,6 +237,7 @@ pub(in crate::exec) fn exec_pty(
         tty_size,
         foreground,
         term_raw,
+        preserve_oflag,
         &mut registry,
     )?;
 
@@ -237,6 +252,7 @@ pub(in crate::exec) fn exec_pty(
     // FIXME (ogsudo): Retry if `/dev/tty` is revoked.
 
     // Flush the terminal
+    closure.tty_pipe.right().set_nonblocking()?;
     closure.tty_pipe.flush_left().ok();
 
     // Restore the terminal settings
@@ -258,7 +274,7 @@ pub(in crate::exec) fn exec_pty(
     exit_reason
 }
 
-fn get_pty() -> io::Result<Pty> {
+fn get_pty(pty_owner: &User) -> io::Result<Pty> {
     let tty_gid = Group::from_name(cstr!("tty"))
         .unwrap_or(None)
         .map(|group| group.gid);
@@ -268,9 +284,8 @@ fn get_pty() -> io::Result<Pty> {
         io::Error::new(io::ErrorKind::NotFound, "unable to open pty")
     })?;
 
-    let euid = User::effective_uid();
     let gid = tty_gid.unwrap_or(User::effective_gid());
-    chown(&pty.path, euid, gid).map_err(|err| {
+    chown(&pty.path, pty_owner.uid, gid).map_err(|err| {
         dev_error!("cannot change owner for pty: {err}");
         err
     })?;
@@ -290,6 +305,7 @@ struct ParentClosure {
     tty_size: TermSize,
     foreground: bool,
     term_raw: bool,
+    preserve_oflag: bool,
     backchannel: ParentBackchannel,
     message_queue: VecDeque<MonitorMessage>,
     backchannel_write_handle: EventHandle,
@@ -313,6 +329,7 @@ impl ParentClosure {
         tty_size: TermSize,
         foreground: bool,
         term_raw: bool,
+        preserve_oflag: bool,
         registry: &mut EventRegistry<Self>,
     ) -> io::Result<Self> {
         // Enable nonblocking assertions as we will poll this inside the event loop.
@@ -340,6 +357,7 @@ impl ParentClosure {
             tty_size,
             foreground,
             term_raw,
+            preserve_oflag,
             backchannel,
             message_queue: VecDeque::new(),
             backchannel_write_handle,
@@ -349,10 +367,19 @@ impl ParentClosure {
     }
 
     fn run(&mut self, registry: EventRegistry<Self>) -> io::Result<ExitReason> {
-        match registry.event_loop(self) {
+        let result = match registry.event_loop(self) {
             StopReason::Break(err) | StopReason::Exit(ParentExit::Backchannel(err)) => Err(err),
             StopReason::Exit(ParentExit::Command(exit_reason)) => Ok(exit_reason),
-        }
+        };
+        // Send red light to the monitor after processing all events
+        retry_while_interrupted(|| self.backchannel.send(&MonitorMessage::Edge)).map_err(
+            |err| {
+                dev_error!("cannot send red light to monitor: {err}");
+                err
+            },
+        )?;
+
+        result
     }
 
     /// Read an event from the backchannel and return the event if it should break the event loop.
@@ -512,7 +539,12 @@ impl ParentClosure {
                     signal_fmt(signal)
                 );
                 if !self.term_raw {
-                    if self.tty_pipe.left_mut().set_raw_mode(false).is_ok() {
+                    if self
+                        .tty_pipe
+                        .left_mut()
+                        .set_raw_mode(false, self.preserve_oflag)
+                        .is_ok()
+                    {
                         self.term_raw = true;
                     }
                     // Resume command in the foreground
@@ -595,7 +627,12 @@ impl ParentClosure {
 
         if self.foreground {
             // We're in the foreground, set tty to raw mode.
-            if self.tty_pipe.left_mut().set_raw_mode(false).is_ok() {
+            if self
+                .tty_pipe
+                .left_mut()
+                .set_raw_mode(false, self.preserve_oflag)
+                .is_ok()
+            {
                 self.term_raw = true;
             }
         } else {
