@@ -16,7 +16,7 @@ fn other_user_does_not_exist() {
     let diagnostic = if sudo_test::is_original_sudo() {
         format!("sudo: unknown user {USERNAME}")
     } else {
-        format!("sudo-rs: user '{USERNAME}' not found")
+        format!("sudo: user '{USERNAME}' not found")
     };
     assert_contains!(output.stderr(), diagnostic);
 }
